
// We are modularizing this manually because the current modularize setting in Emscripten has some issues:
// https://github.com/kripken/emscripten/issues/5820
// In addition, When you use emcc's modularization, it still expects to export a global object called `Module`,
// which is able to be used/called before the WASM is loaded.
// The modularization below exports a promise that loads and resolves to the actual sql.js module.
// That way, this module can't be used before the WASM is finished loading.

// We are going to define a function that a user will call to start loading initializing our Sql.js library
// However, that function might be called multiple times, and on subsequent calls, we don't actually want it to instantiate a new instance of the Module
// Instead, we want to return the previously loaded module

// TODO: Make this not declare a global if used in the browser
var initSqlJsPromise = undefined;

var initSqlJs = function (moduleConfig) {

    if (initSqlJsPromise){
      return initSqlJsPromise;
    }
    // If we're here, we've never called this function before
    initSqlJsPromise = new Promise(function (resolveModule, reject) {

        // We are modularizing this manually because the current modularize setting in Emscripten has some issues:
        // https://github.com/kripken/emscripten/issues/5820

        // The way to affect the loading of emcc compiled modules is to create a variable called `Module` and add
        // properties to it, like `preRun`, `postRun`, etc
        // We are using that to get notified when the WASM has finished loading.
        // Only then will we return our promise

        // If they passed in a moduleConfig object, use that
        // Otherwise, initialize Module to the empty object
        var Module = typeof moduleConfig !== 'undefined' ? moduleConfig : {};

        // EMCC only allows for a single onAbort function (not an array of functions)
        // So if the user defined their own onAbort function, we remember it and call it
        var originalOnAbortFunction = Module['onAbort'];
        Module['onAbort'] = function (errorThatCausedAbort) {
            reject(new Error(errorThatCausedAbort));
            if (originalOnAbortFunction){
              originalOnAbortFunction(errorThatCausedAbort);
            }
        };

        Module['postRun'] = Module['postRun'] || [];
        Module['postRun'].push(function () {
            // When Emscripted calls postRun, this promise resolves with the built Module
            resolveModule(Module);
        });

        // There is a section of code in the emcc-generated code below that looks like this:
        // (Note that this is lowercase `module`)
        // if (typeof module !== 'undefined') {
        //     module['exports'] = Module;
        // }
        // When that runs, it's going to overwrite our own modularization export efforts in shell-post.js!
        // The only way to tell emcc not to emit it is to pass the MODULARIZE=1 or MODULARIZE_INSTANCE=1 flags,
        // but that carries with it additional unnecessary baggage/bugs we don't want either.
        // So, we have three options:
        // 1) We undefine `module`
        // 2) We remember what `module['exports']` was at the beginning of this function and we restore it later
        // 3) We write a script to remove those lines of code as part of the Make process.
        //
        // Since those are the only lines of code that care about module, we will undefine it. It's the most straightforward
        // of the options, and has the side effect of reducing emcc's efforts to modify the module if its output were to change in the future.
        // That's a nice side effect since we're handling the modularization efforts ourselves
        module = undefined;

        // The emcc-generated code and shell-post.js code goes below,
        // meaning that all of it runs inside of this promise. If anything throws an exception, our promise will abort

var Module;Module||(Module=typeof Module !== 'undefined' ? Module : {});null;
Module.onRuntimeInitialized=function(){function a(h,m){this.Ka=h;this.db=m;this.Ja=1;this.ob=[]}function b(h,m){this.db=m;m=d(h)+1;this.$a=aa(m);if(null===this.$a)throw Error("Unable to allocate memory for the SQL string");p(h,t,this.$a,m);this.lb=this.$a;this.Xa=this.Eb=null}function c(h,{filename:m=!1}={}){!1===m?(this.filename="dbfile_"+(4294967295*Math.random()>>>0),this.Mc=!0,null!=h&&y.rb("/",this.filename,h,!0,!0)):this.filename=h;this.handleError(g(this.filename,e));this.db=B(e,"i32");xb(this.db);
this.fb={};this.Qa={}}var e=C(4),f=Module.cwrap,g=f("sqlite3_open","number",["string","number"]),k=f("sqlite3_close_v2","number",["number"]),l=f("sqlite3_exec","number",["number","string","number","number","number"]),q=f("sqlite3_changes","number",["number"]),n=f("sqlite3_prepare_v2","number",["number","string","number","number","number"]),r=f("sqlite3_sql","string",["number"]),x=f("sqlite3_normalized_sql","string",["number"]),z=f("sqlite3_prepare_v2","number",["number","number","number","number",
"number"]),D=f("sqlite3_bind_text","number",["number","number","number","number","number"]),A=f("sqlite3_bind_blob","number",["number","number","number","number","number"]),S=f("sqlite3_bind_double","number",["number","number","number"]),Y=f("sqlite3_bind_int","number",["number","number","number"]),T=f("sqlite3_bind_parameter_index","number",["number","string"]),Ia=f("sqlite3_step","number",["number"]),E=f("sqlite3_errmsg","string",["number"]),yb=f("sqlite3_column_count","number",["number"]),zb=f("sqlite3_data_count",
"number",["number"]),Ab=f("sqlite3_column_double","number",["number","number"]),$a=f("sqlite3_column_text","string",["number","number"]),Bb=f("sqlite3_column_blob","number",["number","number"]),Cb=f("sqlite3_column_bytes","number",["number","number"]),Db=f("sqlite3_column_type","number",["number","number"]),Eb=f("sqlite3_column_name","string",["number","number"]),Fb=f("sqlite3_reset","number",["number"]),Gb=f("sqlite3_clear_bindings","number",["number"]),Hb=f("sqlite3_finalize","number",["number"]),
Ib=f("sqlite3_create_function_v2","number","number string number number number number number number number".split(" ")),Jb=f("sqlite3_value_type","number",["number"]),Kb=f("sqlite3_value_bytes","number",["number"]),Lb=f("sqlite3_value_text","string",["number"]),Mb=f("sqlite3_value_blob","number",["number"]),Nb=f("sqlite3_value_double","number",["number"]),Ob=f("sqlite3_result_double","",["number","number"]),ab=f("sqlite3_result_null","",["number"]),Pb=f("sqlite3_result_text","",["number","string",
"number","number"]),Qb=f("sqlite3_result_blob","",["number","number","number","number"]),Rb=f("sqlite3_result_int","",["number","number"]),bb=f("sqlite3_result_error","",["number","string","number"]),xb=f("RegisterExtensionFunctions","number",["number"]);a.prototype.bind=function(h){if(!this.Ka)throw"Statement closed";this.reset();return Array.isArray(h)?this.nc(h):null!=h&&"object"===typeof h?this.oc(h):!0};a.prototype.step=function(){if(!this.Ka)throw"Statement closed";this.Ja=1;var h=Ia(this.Ka);
switch(h){case 100:return!0;case 101:return!1;default:throw this.db.handleError(h);}};a.prototype.Xb=function(h){null==h&&(h=this.Ja,this.Ja+=1);return Ab(this.Ka,h)};a.prototype.Fc=function(h){null==h&&(h=this.Ja,this.Ja+=1);h=$a(this.Ka,h);if("function"!==typeof BigInt)throw Error("BigInt is not supported");return BigInt(h)};a.prototype.Hc=function(h){null==h&&(h=this.Ja,this.Ja+=1);return $a(this.Ka,h)};a.prototype.getBlob=function(h){null==h&&(h=this.Ja,this.Ja+=1);var m=Cb(this.Ka,h);h=Bb(this.Ka,
h);for(var u=new Uint8Array(m),v=0;v<m;v+=1)u[v]=I[h+v];return u};a.prototype.get=function(h,m){m=m||{};null!=h&&this.bind(h)&&this.step();h=[];for(var u=zb(this.Ka),v=0;v<u;v+=1)switch(Db(this.Ka,v)){case 1:var w=m.useBigInt?this.Fc(v):this.Xb(v);h.push(w);break;case 2:h.push(this.Xb(v));break;case 3:h.push(this.Hc(v));break;case 4:h.push(this.getBlob(v));break;default:h.push(null)}return h};a.prototype.getColumnNames=function(){for(var h=[],m=yb(this.Ka),u=0;u<m;u+=1)h.push(Eb(this.Ka,u));return h};
a.prototype.getAsObject=function(h,m){h=this.get(h,m);m=this.getColumnNames();for(var u={},v=0;v<m.length;v+=1)u[m[v]]=h[v];return u};a.prototype.getSQL=function(){return r(this.Ka)};a.prototype.getNormalizedSQL=function(){return x(this.Ka)};a.prototype.run=function(h){null!=h&&this.bind(h);this.step();return this.reset()};a.prototype.Mb=function(h,m){null==m&&(m=this.Ja,this.Ja+=1);h=ba(h);var u=ca(h);this.ob.push(u);this.db.handleError(D(this.Ka,m,u,h.length-1,0))};a.prototype.mc=function(h,m){null==
m&&(m=this.Ja,this.Ja+=1);var u=ca(h);this.ob.push(u);this.db.handleError(A(this.Ka,m,u,h.length,0))};a.prototype.Lb=function(h,m){null==m&&(m=this.Ja,this.Ja+=1);this.db.handleError((h===(h|0)?Y:S)(this.Ka,m,h))};a.prototype.pc=function(h){null==h&&(h=this.Ja,this.Ja+=1);A(this.Ka,h,0,0,0)};a.prototype.Nb=function(h,m){null==m&&(m=this.Ja,this.Ja+=1);switch(typeof h){case "string":this.Mb(h,m);return;case "number":this.Lb(h,m);return;case "bigint":this.Mb(h.toString(),m);return;case "boolean":this.Lb(h+
0,m);return;case "object":if(null===h){this.pc(m);return}if(null!=h.length){this.mc(h,m);return}}throw"Wrong API use : tried to bind a value of an unknown type ("+h+").";};a.prototype.oc=function(h){var m=this;Object.keys(h).forEach(function(u){var v=T(m.Ka,u);0!==v&&m.Nb(h[u],v)});return!0};a.prototype.nc=function(h){for(var m=0;m<h.length;m+=1)this.Nb(h[m],m+1);return!0};a.prototype.reset=function(){this.freemem();return 0===Gb(this.Ka)&&0===Fb(this.Ka)};a.prototype.freemem=function(){for(var h;void 0!==
(h=this.ob.pop());)da(h)};a.prototype.free=function(){this.freemem();var h=0===Hb(this.Ka);delete this.db.fb[this.Ka];this.Ka=0;return h};b.prototype.next=function(){if(null===this.$a)return{done:!0};null!==this.Xa&&(this.Xa.free(),this.Xa=null);if(!this.db.db)throw this.tb(),Error("Database closed");var h=fa(),m=C(4);ha(e);ha(m);try{this.db.handleError(z(this.db.db,this.lb,-1,e,m));this.lb=B(m,"i32");var u=B(e,"i32");if(0===u)return this.tb(),{done:!0};this.Xa=new a(u,this.db);this.db.fb[u]=this.Xa;
return{value:this.Xa,done:!1}}catch(v){throw this.Eb=J(this.lb),this.tb(),v;}finally{ia(h)}};b.prototype.tb=function(){da(this.$a);this.$a=null};b.prototype.getRemainingSQL=function(){return null!==this.Eb?this.Eb:J(this.lb)};"function"===typeof Symbol&&"symbol"===typeof Symbol.iterator&&(b.prototype[Symbol.iterator]=function(){return this});c.prototype.run=function(h,m){if(!this.db)throw"Database closed";if(m){h=this.prepare(h,m);try{h.step()}finally{h.free()}}else this.handleError(l(this.db,h,0,
0,e));return this};c.prototype.exec=function(h,m,u){if(!this.db)throw"Database closed";var v=fa(),w=null;try{var F=d(h)+1,H=C(F);p(h,I,H,F);var ea=H;var Z=C(4);for(h=[];0!==B(ea,"i8");){ha(e);ha(Z);this.handleError(z(this.db,ea,-1,e,Z));var G=B(e,"i32");ea=B(Z,"i32");if(0!==G){F=null;w=new a(G,this);for(null!=m&&w.bind(m);w.step();)null===F&&(F={columns:w.getColumnNames(),values:[]},h.push(F)),F.values.push(w.get(null,u));w.free()}}return h}catch(K){throw w&&w.free(),K;}finally{ia(v)}};c.prototype.each=
function(h,m,u,v,w){"function"===typeof m&&(v=u,u=m,m=void 0);h=this.prepare(h,m);try{for(;h.step();)u(h.getAsObject(null,w))}finally{h.free()}if("function"===typeof v)return v()};c.prototype.prepare=function(h,m){ha(e);this.handleError(n(this.db,h,-1,e,0));h=B(e,"i32");if(0===h)throw"Nothing to prepare";var u=new a(h,this);null!=m&&u.bind(m);return this.fb[h]=u};c.prototype.iterateStatements=function(h){return new b(h,this)};c.prototype["export"]=function(){Object.values(this.fb).forEach(function(m){m.free()});
Object.values(this.Qa).forEach(ja);this.Qa={};this.handleError(k(this.db));var h=y.readFile(this.filename,{encoding:"binary"});this.handleError(g(this.filename,e));this.db=B(e,"i32");return h};c.prototype.close=function(){null!==this.db&&(Object.values(this.fb).forEach(function(h){h.free()}),Object.values(this.Qa).forEach(ja),this.Qa={},this.handleError(k(this.db)),this.Mc&&y.unlink("/"+this.filename),this.db=null)};c.prototype.handleError=function(h){if(0===h)return null;h=E(this.db);throw Error(h);
};c.prototype.getRowsModified=function(){return q(this.db)};c.prototype.create_function=function(h,m){Object.prototype.hasOwnProperty.call(this.Qa,h)&&(ja(this.Qa[h]),delete this.Qa[h]);var u=ka(function(v,w,F){for(var H,ea=[],Z=0;Z<w;Z+=1){var G=B(F+4*Z,"i32"),K=Jb(G);if(1===K||2===K)G=Nb(G);else if(3===K)G=Lb(G);else if(4===K){K=G;G=Kb(K);K=Mb(K);for(var cb=new Uint8Array(G),wa=0;wa<G;wa+=1)cb[wa]=I[K+wa];G=cb}else G=null;ea.push(G)}try{H=m.apply(null,ea)}catch(Sb){bb(v,Sb,-1);return}switch(typeof H){case "boolean":Rb(v,
H?1:0);break;case "number":Ob(v,H);break;case "string":Pb(v,H,-1,-1);break;case "object":null===H?ab(v):null!=H.length?(w=ca(H),Qb(v,w,H.length,-1),da(w)):bb(v,"Wrong API use : tried to return a value of an unknown type ("+H+").",-1);break;default:ab(v)}},"viii");this.Qa[h]=u;this.handleError(Ib(this.db,h,m.length,1,0,u,0,0,0));return this};Module.Database=c;const na=new Map;Module.register_for_idb=h=>{const m=ka(function(w,F){w=na.get(w);return h.lock(w,F)?0:5},"iii"),u=ka(function(w,F){w=na.get(w);
h.unlock(w,F);return 0},"iii"),v=ka(function(w,F){w=J(w);na.set(F,w)},"vii");Module._register_for_idb(m,u,v)};Module.cleanup_file=h=>{const m=[...na.entries()].find(u=>u[1]===h);na.delete(m[0])};Module.reset_filesystem=()=>{y.root=null;y.ec()}};var la=Object.assign({},Module),ma="./this.program",oa="object"==typeof window,pa="function"==typeof importScripts,qa="object"==typeof process&&"object"==typeof process.versions&&"string"==typeof process.versions.node,L="",ra,sa,ta,fs,ua,va;
if(qa)L=pa?require("path").dirname(L)+"/":__dirname+"/",va=()=>{ua||(fs=require("fs"),ua=require("path"))},ra=function(a,b){va();a=ua.normalize(a);return fs.readFileSync(a,b?void 0:"utf8")},ta=a=>{a=ra(a,!0);a.buffer||(a=new Uint8Array(a));return a},sa=(a,b,c)=>{va();a=ua.normalize(a);fs.readFile(a,function(e,f){e?c(e):b(f.buffer)})},1<process.argv.length&&(ma=process.argv[1].replace(/\\/g,"/")),process.argv.slice(2),"undefined"!=typeof module&&(module.exports=Module),Module.inspect=function(){return"[Emscripten Module object]"};
else if(oa||pa)pa?L=self.location.href:"undefined"!=typeof document&&document.currentScript&&(L=document.currentScript.src),L=0!==L.indexOf("blob:")?L.substr(0,L.replace(/[?#].*/,"").lastIndexOf("/")+1):"",ra=a=>{var b=new XMLHttpRequest;b.open("GET",a,!1);b.send(null);return b.responseText},pa&&(ta=a=>{var b=new XMLHttpRequest;b.open("GET",a,!1);b.responseType="arraybuffer";b.send(null);return new Uint8Array(b.response)}),sa=(a,b,c)=>{var e=new XMLHttpRequest;e.open("GET",a,!0);e.responseType="arraybuffer";
e.onload=()=>{200==e.status||0==e.status&&e.response?b(e.response):c()};e.onerror=c;e.send(null)};var xa=Module.print||console.log.bind(console),M=Module.printErr||console.warn.bind(console);Object.assign(Module,la);la=null;Module.thisProgram&&(ma=Module.thisProgram);var ya=[],za;
function ka(a,b){if(!za){za=new WeakMap;for(var c=N.length,e=0;e<0+c;e++){var f=N.get(e);f&&za.set(f,e)}}if(za.has(a))return za.get(a);if(ya.length)c=ya.pop();else{try{N.grow(1)}catch(l){if(!(l instanceof RangeError))throw l;throw"Unable to grow wasm table. Set ALLOW_TABLE_GROWTH.";}c=N.length-1}try{N.set(c,a)}catch(l){if(!(l instanceof TypeError))throw l;if("function"==typeof WebAssembly.Function){f={i:"i32",j:"i64",f:"f32",d:"f64"};var g={parameters:[],results:"v"==b[0]?[]:[f[b[0]]]};for(e=1;e<
b.length;++e)g.parameters.push(f[b[e]]);b=new WebAssembly.Function(g,a)}else{f=[1,0,1,96];g=b.slice(0,1);b=b.slice(1);var k={i:127,j:126,f:125,d:124};f.push(b.length);for(e=0;e<b.length;++e)f.push(k[b[e]]);"v"==g?f.push(0):f=f.concat([1,k[g]]);f[1]=f.length-2;b=new Uint8Array([0,97,115,109,1,0,0,0].concat(f,[2,7,1,1,101,1,102,0,0,7,5,1,1,102,0,0]));b=new WebAssembly.Module(b);b=(new WebAssembly.Instance(b,{e:{f:a}})).exports.f}N.set(c,b)}za.set(a,c);return c}
function ja(a){za.delete(N.get(a));ya.push(a)}var Aa;Module.wasmBinary&&(Aa=Module.wasmBinary);var noExitRuntime=Module.noExitRuntime||!0;"object"!=typeof WebAssembly&&O("no native wasm support detected");
function ha(a){var b="i32";"*"===b.charAt(b.length-1)&&(b="i32");switch(b){case "i1":I[a>>0]=0;break;case "i8":I[a>>0]=0;break;case "i16":Ba[a>>1]=0;break;case "i32":P[a>>2]=0;break;case "i64":Q=[0,(R=0,1<=+Math.abs(R)?0<R?(Math.min(+Math.floor(R/4294967296),4294967295)|0)>>>0:~~+Math.ceil((R-+(~~R>>>0))/4294967296)>>>0:0)];P[a>>2]=Q[0];P[a+4>>2]=Q[1];break;case "float":Ca[a>>2]=0;break;case "double":Da[a>>3]=0;break;default:O("invalid type for setValue: "+b)}}
function B(a,b="i8"){"*"===b.charAt(b.length-1)&&(b="i32");switch(b){case "i1":return I[a>>0];case "i8":return I[a>>0];case "i16":return Ba[a>>1];case "i32":return P[a>>2];case "i64":return P[a>>2];case "float":return Ca[a>>2];case "double":return Number(Da[a>>3]);default:O("invalid type for getValue: "+b)}return null}var Ea,Fa=!1;
function Ga(a,b,c,e){var f={string:function(n){var r=0;if(null!==n&&void 0!==n&&0!==n){var x=(n.length<<2)+1;r=C(x);p(n,t,r,x)}return r},array:function(n){var r=C(n.length);I.set(n,r);return r}};a=Module["_"+a];var g=[],k=0;if(e)for(var l=0;l<e.length;l++){var q=f[c[l]];q?(0===k&&(k=fa()),g[l]=q(e[l])):g[l]=e[l]}c=a.apply(null,g);return c=function(n){0!==k&&ia(k);return"string"===b?J(n):"boolean"===b?!!n:n}(c)}var Ha=0,Ja=1;
function ca(a){var b=Ha==Ja?C(a.length):aa(a.length);a.subarray||a.slice||(a=new Uint8Array(a));t.set(a,b);return b}var Ka="undefined"!=typeof TextDecoder?new TextDecoder("utf8"):void 0;
function La(a,b,c){var e=b+c;for(c=b;a[c]&&!(c>=e);)++c;if(16<c-b&&a.buffer&&Ka)return Ka.decode(a.subarray(b,c));for(e="";b<c;){var f=a[b++];if(f&128){var g=a[b++]&63;if(192==(f&224))e+=String.fromCharCode((f&31)<<6|g);else{var k=a[b++]&63;f=224==(f&240)?(f&15)<<12|g<<6|k:(f&7)<<18|g<<12|k<<6|a[b++]&63;65536>f?e+=String.fromCharCode(f):(f-=65536,e+=String.fromCharCode(55296|f>>10,56320|f&1023))}}else e+=String.fromCharCode(f)}return e}function J(a,b){return a?La(t,a,b):""}
function p(a,b,c,e){if(!(0<e))return 0;var f=c;e=c+e-1;for(var g=0;g<a.length;++g){var k=a.charCodeAt(g);if(55296<=k&&57343>=k){var l=a.charCodeAt(++g);k=65536+((k&1023)<<10)|l&1023}if(127>=k){if(c>=e)break;b[c++]=k}else{if(2047>=k){if(c+1>=e)break;b[c++]=192|k>>6}else{if(65535>=k){if(c+2>=e)break;b[c++]=224|k>>12}else{if(c+3>=e)break;b[c++]=240|k>>18;b[c++]=128|k>>12&63}b[c++]=128|k>>6&63}b[c++]=128|k&63}}b[c]=0;return c-f}
function d(a){for(var b=0,c=0;c<a.length;++c){var e=a.charCodeAt(c);55296<=e&&57343>=e&&(e=65536+((e&1023)<<10)|a.charCodeAt(++c)&1023);127>=e?++b:b=2047>=e?b+2:65535>=e?b+3:b+4}return b}function Ma(a){var b=d(a)+1,c=aa(b);c&&p(a,I,c,b);return c}var Na,I,t,Ba,P,Ca,Da;
function Oa(){var a=Ea.buffer;Na=a;Module.HEAP8=I=new Int8Array(a);Module.HEAP16=Ba=new Int16Array(a);Module.HEAP32=P=new Int32Array(a);Module.HEAPU8=t=new Uint8Array(a);Module.HEAPU16=new Uint16Array(a);Module.HEAPU32=new Uint32Array(a);Module.HEAPF32=Ca=new Float32Array(a);Module.HEAPF64=Da=new Float64Array(a)}var N,Pa=[],Qa=[],Ra=[];function Sa(){var a=Module.preRun.shift();Pa.unshift(a)}var Ta=0,Ua=null,Va=null;
function Wa(){Ta++;Module.monitorRunDependencies&&Module.monitorRunDependencies(Ta)}function Xa(){Ta--;Module.monitorRunDependencies&&Module.monitorRunDependencies(Ta);if(0==Ta&&(null!==Ua&&(clearInterval(Ua),Ua=null),Va)){var a=Va;Va=null;a()}}Module.preloadedImages={};Module.preloadedAudios={};function O(a){if(Module.onAbort)Module.onAbort(a);a="Aborted("+a+")";M(a);Fa=!0;throw new WebAssembly.RuntimeError(a+". Build with -s ASSERTIONS=1 for more info.");}
function Ya(){return U.startsWith("data:application/octet-stream;base64,")}var U;U="sql-wasm.wasm";if(!Ya()){var Za=U;U=Module.locateFile?Module.locateFile(Za,L):L+Za}function db(){var a=U;try{if(a==U&&Aa)return new Uint8Array(Aa);if(ta)return ta(a);throw"both async and sync fetching of the wasm failed";}catch(b){O(b)}}
function eb(){if(!Aa&&(oa||pa)){if("function"==typeof fetch&&!U.startsWith("file://"))return fetch(U,{credentials:"same-origin"}).then(function(a){if(!a.ok)throw"failed to load wasm binary file at '"+U+"'";return a.arrayBuffer()}).catch(function(){return db()});if(sa)return new Promise(function(a,b){sa(U,function(c){a(new Uint8Array(c))},b)})}return Promise.resolve().then(function(){return db()})}var R,Q;
function fb(a){for(;0<a.length;){var b=a.shift();if("function"==typeof b)b(Module);else{var c=b.bd;"number"==typeof c?void 0===b.qb?N.get(c)():N.get(c)(b.qb):c(void 0===b.qb?null:b.qb)}}}function gb(a,b){for(var c=0,e=a.length-1;0<=e;e--){var f=a[e];"."===f?a.splice(e,1):".."===f?(a.splice(e,1),c++):c&&(a.splice(e,1),c--)}if(b)for(;c;c--)a.unshift("..");return a}
function hb(a){var b="/"===a.charAt(0),c="/"===a.substr(-1);(a=gb(a.split("/").filter(function(e){return!!e}),!b).join("/"))||b||(a=".");a&&c&&(a+="/");return(b?"/":"")+a}function ib(a){var b=/^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/.exec(a).slice(1);a=b[0];b=b[1];if(!a&&!b)return".";b&&(b=b.substr(0,b.length-1));return a+b}function V(a){if("/"===a)return"/";a=hb(a);a=a.replace(/\/$/,"");var b=a.lastIndexOf("/");return-1===b?a:a.substr(b+1)}
function jb(a,b){return hb(a+"/"+b)}function kb(){if("object"==typeof crypto&&"function"==typeof crypto.getRandomValues){var a=new Uint8Array(1);return function(){crypto.getRandomValues(a);return a[0]}}if(qa)try{var b=require("crypto");return function(){return b.randomBytes(1)[0]}}catch(c){}return function(){O("randomDevice")}}
function lb(){for(var a="",b=!1,c=arguments.length-1;-1<=c&&!b;c--){b=0<=c?arguments[c]:y.cwd();if("string"!=typeof b)throw new TypeError("Arguments to path.resolve must be strings");if(!b)return"";a=b+"/"+a;b="/"===b.charAt(0)}a=gb(a.split("/").filter(function(e){return!!e}),!b).join("/");return(b?"/":"")+a||"."}
function mb(a,b){function c(k){for(var l=0;l<k.length&&""===k[l];l++);for(var q=k.length-1;0<=q&&""===k[q];q--);return l>q?[]:k.slice(l,q-l+1)}a=lb(a).substr(1);b=lb(b).substr(1);a=c(a.split("/"));b=c(b.split("/"));for(var e=Math.min(a.length,b.length),f=e,g=0;g<e;g++)if(a[g]!==b[g]){f=g;break}e=[];for(g=f;g<a.length;g++)e.push("..");e=e.concat(b.slice(f));return e.join("/")}var nb=[];function ob(a,b){nb[a]={input:[],output:[],Za:b};y.Ib(a,pb)}
var pb={open:function(a){var b=nb[a.node.rdev];if(!b)throw new y.ErrnoError(43);a.tty=b;a.seekable=!1},close:function(a){a.tty.Za.flush(a.tty)},flush:function(a){a.tty.Za.flush(a.tty)},read:function(a,b,c,e){if(!a.tty||!a.tty.Za.Yb)throw new y.ErrnoError(60);for(var f=0,g=0;g<e;g++){try{var k=a.tty.Za.Yb(a.tty)}catch(l){throw new y.ErrnoError(29);}if(void 0===k&&0===f)throw new y.ErrnoError(6);if(null===k||void 0===k)break;f++;b[c+g]=k}f&&(a.node.timestamp=Date.now());return f},write:function(a,b,
c,e){if(!a.tty||!a.tty.Za.Fb)throw new y.ErrnoError(60);try{for(var f=0;f<e;f++)a.tty.Za.Fb(a.tty,b[c+f])}catch(g){throw new y.ErrnoError(29);}e&&(a.node.timestamp=Date.now());return f}},qb={Yb:function(a){if(!a.input.length){var b=null;if(qa){var c=Buffer.alloc(256),e=0;try{e=fs.readSync(process.stdin.fd,c,0,256,-1)}catch(f){if(f.toString().includes("EOF"))e=0;else throw f;}0<e?b=c.slice(0,e).toString("utf-8"):b=null}else"undefined"!=typeof window&&"function"==typeof window.prompt?(b=window.prompt("Input: "),
null!==b&&(b+="\n")):"function"==typeof readline&&(b=readline(),null!==b&&(b+="\n"));if(!b)return null;a.input=ba(b,!0)}return a.input.shift()},Fb:function(a,b){null===b||10===b?(xa(La(a.output,0)),a.output=[]):0!=b&&a.output.push(b)},flush:function(a){a.output&&0<a.output.length&&(xa(La(a.output,0)),a.output=[])}},rb={Fb:function(a,b){null===b||10===b?(M(La(a.output,0)),a.output=[]):0!=b&&a.output.push(b)},flush:function(a){a.output&&0<a.output.length&&(M(La(a.output,0)),a.output=[])}},W={Oa:null,
mount:function(){return W.createNode(null,"/",16895,0)},createNode:function(a,b,c,e){if(y.Ic(c)||y.isFIFO(c))throw new y.ErrnoError(63);W.Oa||(W.Oa={dir:{node:{getattr:W.node_ops.getattr,setattr:W.node_ops.setattr,lookup:W.node_ops.lookup,mknod:W.node_ops.mknod,rename:W.node_ops.rename,unlink:W.node_ops.unlink,rmdir:W.node_ops.rmdir,readdir:W.node_ops.readdir,symlink:W.node_ops.symlink},stream:{llseek:W.stream_ops.llseek}},file:{node:{getattr:W.node_ops.getattr,setattr:W.node_ops.setattr},stream:{llseek:W.stream_ops.llseek,
read:W.stream_ops.read,write:W.stream_ops.write,allocate:W.stream_ops.allocate,mmap:W.stream_ops.mmap,msync:W.stream_ops.msync}},link:{node:{getattr:W.node_ops.getattr,setattr:W.node_ops.setattr,readlink:W.node_ops.readlink},stream:{}},Pb:{node:{getattr:W.node_ops.getattr,setattr:W.node_ops.setattr},stream:y.tc}});c=y.createNode(a,b,c,e);y.isDir(c.mode)?(c.node_ops=W.Oa.dir.node,c.stream_ops=W.Oa.dir.stream,c.Ha={}):y.isFile(c.mode)?(c.node_ops=W.Oa.file.node,c.stream_ops=W.Oa.file.stream,c.La=0,
c.Ha=null):y.Ya(c.mode)?(c.node_ops=W.Oa.link.node,c.stream_ops=W.Oa.link.stream):y.ib(c.mode)&&(c.node_ops=W.Oa.Pb.node,c.stream_ops=W.Oa.Pb.stream);c.timestamp=Date.now();a&&(a.Ha[b]=c,a.timestamp=c.timestamp);return c},cd:function(a){return a.Ha?a.Ha.subarray?a.Ha.subarray(0,a.La):new Uint8Array(a.Ha):new Uint8Array(0)},Tb:function(a,b){var c=a.Ha?a.Ha.length:0;c>=b||(b=Math.max(b,c*(1048576>c?2:1.125)>>>0),0!=c&&(b=Math.max(b,256)),c=a.Ha,a.Ha=new Uint8Array(b),0<a.La&&a.Ha.set(c.subarray(0,a.La),
0))},Uc:function(a,b){if(a.La!=b)if(0==b)a.Ha=null,a.La=0;else{var c=a.Ha;a.Ha=new Uint8Array(b);c&&a.Ha.set(c.subarray(0,Math.min(b,a.La)));a.La=b}},node_ops:{getattr:function(a){var b={};b.dev=y.ib(a.mode)?a.id:1;b.ino=a.id;b.mode=a.mode;b.nlink=1;b.uid=0;b.gid=0;b.rdev=a.rdev;y.isDir(a.mode)?b.size=4096:y.isFile(a.mode)?b.size=a.La:y.Ya(a.mode)?b.size=a.link.length:b.size=0;b.atime=new Date(a.timestamp);b.mtime=new Date(a.timestamp);b.ctime=new Date(a.timestamp);b.qc=4096;b.blocks=Math.ceil(b.size/
b.qc);return b},setattr:function(a,b){void 0!==b.mode&&(a.mode=b.mode);void 0!==b.timestamp&&(a.timestamp=b.timestamp);void 0!==b.size&&W.Uc(a,b.size)},lookup:function(){throw y.vb[44];},mknod:function(a,b,c,e){return W.createNode(a,b,c,e)},rename:function(a,b,c){if(y.isDir(a.mode)){try{var e=y.lookupNode(b,c)}catch(g){}if(e)for(var f in e.Ha)throw new y.ErrnoError(55);}delete a.parent.Ha[a.name];a.parent.timestamp=Date.now();a.name=c;b.Ha[c]=a;b.timestamp=a.parent.timestamp;a.parent=b},unlink:function(a,
b){delete a.Ha[b];a.timestamp=Date.now()},rmdir:function(a,b){var c=y.lookupNode(a,b),e;for(e in c.Ha)throw new y.ErrnoError(55);delete a.Ha[b];a.timestamp=Date.now()},readdir:function(a){var b=[".",".."],c;for(c in a.Ha)a.Ha.hasOwnProperty(c)&&b.push(c);return b},symlink:function(a,b,c){a=W.createNode(a,b,41471,0);a.link=c;return a},readlink:function(a){if(!y.Ya(a.mode))throw new y.ErrnoError(28);return a.link}},stream_ops:{read:function(a,b,c,e,f){var g=a.node.Ha;if(f>=a.node.La)return 0;a=Math.min(a.node.La-
f,e);if(8<a&&g.subarray)b.set(g.subarray(f,f+a),c);else for(e=0;e<a;e++)b[c+e]=g[f+e];return a},write:function(a,b,c,e,f,g){b.buffer===I.buffer&&(g=!1);if(!e)return 0;a=a.node;a.timestamp=Date.now();if(b.subarray&&(!a.Ha||a.Ha.subarray)){if(g)return a.Ha=b.subarray(c,c+e),a.La=e;if(0===a.La&&0===f)return a.Ha=b.slice(c,c+e),a.La=e;if(f+e<=a.La)return a.Ha.set(b.subarray(c,c+e),f),e}W.Tb(a,f+e);if(a.Ha.subarray&&b.subarray)a.Ha.set(b.subarray(c,c+e),f);else for(g=0;g<e;g++)a.Ha[f+g]=b[c+g];a.La=Math.max(a.La,
f+e);return e},llseek:function(a,b,c){1===c?b+=a.position:2===c&&y.isFile(a.node.mode)&&(b+=a.node.La);if(0>b)throw new y.ErrnoError(28);return b},allocate:function(a,b,c){W.Tb(a.node,b+c);a.node.La=Math.max(a.node.La,b+c)},mmap:function(a,b,c,e,f,g){if(0!==b)throw new y.ErrnoError(28);if(!y.isFile(a.node.mode))throw new y.ErrnoError(43);a=a.node.Ha;if(g&2||a.buffer!==Na){if(0<e||e+c<a.length)a.subarray?a=a.subarray(e,e+c):a=Array.prototype.slice.call(a,e,e+c);e=!0;c=65536*Math.ceil(c/65536);(g=sb(65536,
c))?(t.fill(0,g,g+c),c=g):c=0;if(!c)throw new y.ErrnoError(48);I.set(a,c)}else e=!1,c=a.byteOffset;return{Tc:c,lc:e}},msync:function(a,b,c,e,f){if(!y.isFile(a.node.mode))throw new y.ErrnoError(43);if(f&2)return 0;W.stream_ops.write(a,b,0,e,c,!1);return 0}}};function tb(a,b,c){var e="al "+a;sa(a,function(f){f||O('Loading data file "'+a+'" failed (no arrayBuffer).');b(new Uint8Array(f));e&&Xa()},function(){if(c)c();else throw'Loading data file "'+a+'" failed.';});e&&Wa()}
var y={root:null,eb:[],Rb:{},streams:[],Oc:1,Na:null,Qb:"/",zb:!1,bc:!0,ErrnoError:null,vb:{},Cc:null,mb:0,lookupPath:(a,b={})=>{a=lb(y.cwd(),a);if(!a)return{path:"",node:null};b=Object.assign({ub:!0,Hb:0},b);if(8<b.Hb)throw new y.ErrnoError(32);a=gb(a.split("/").filter(k=>!!k),!1);for(var c=y.root,e="/",f=0;f<a.length;f++){var g=f===a.length-1;if(g&&b.parent)break;c=y.lookupNode(c,a[f]);e=jb(e,a[f]);y.Ua(c)&&(!g||g&&b.ub)&&(c=c.cb.root);if(!g||b.Ma)for(g=0;y.Ya(c.mode);)if(c=y.readlink(e),e=lb(ib(e),
c),c=y.lookupPath(e,{Hb:b.Hb+1}).node,40<g++)throw new y.ErrnoError(32);}return{path:e,node:c}},Ra:a=>{for(var b;;){if(y.isRoot(a))return a=a.mount.dc,b?"/"!==a[a.length-1]?a+"/"+b:a+b:a;b=b?a.name+"/"+b:a.name;a=a.parent}},yb:(a,b)=>{for(var c=0,e=0;e<b.length;e++)c=(c<<5)-c+b.charCodeAt(e)|0;return(a+c>>>0)%y.Na.length},$b:a=>{var b=y.yb(a.parent.id,a.name);a.Wa=y.Na[b];y.Na[b]=a},ac:a=>{var b=y.yb(a.parent.id,a.name);if(y.Na[b]===a)y.Na[b]=a.Wa;else for(b=y.Na[b];b;){if(b.Wa===a){b.Wa=a.Wa;break}b=
b.Wa}},lookupNode:(a,b)=>{var c=y.Kc(a);if(c)throw new y.ErrnoError(c,a);for(c=y.Na[y.yb(a.id,b)];c;c=c.Wa){var e=c.name;if(c.parent.id===a.id&&e===b)return c}return y.lookup(a,b)},createNode:(a,b,c,e)=>{a=new y.FSNode(a,b,c,e);y.$b(a);return a},sb:a=>{y.ac(a)},isRoot:a=>a===a.parent,Ua:a=>!!a.cb,isFile:a=>32768===(a&61440),isDir:a=>16384===(a&61440),Ya:a=>40960===(a&61440),ib:a=>8192===(a&61440),Ic:a=>24576===(a&61440),isFIFO:a=>4096===(a&61440),isSocket:a=>49152===(a&49152),Dc:{r:0,"r+":2,w:577,
"w+":578,a:1089,"a+":1090},Nc:a=>{var b=y.Dc[a];if("undefined"==typeof b)throw Error("Unknown file open mode: "+a);return b},Ub:a=>{var b=["r","w","rw"][a&3];a&512&&(b+="w");return b},Ta:(a,b)=>{if(y.bc)return 0;if(!b.includes("r")||a.mode&292){if(b.includes("w")&&!(a.mode&146)||b.includes("x")&&!(a.mode&73))return 2}else return 2;return 0},Kc:a=>{var b=y.Ta(a,"x");return b?b:a.node_ops.lookup?0:2},Db:(a,b)=>{try{return y.lookupNode(a,b),20}catch(c){}return y.Ta(a,"wx")},jb:(a,b,c)=>{try{var e=y.lookupNode(a,
b)}catch(f){return f.Ia}if(a=y.Ta(a,"wx"))return a;if(c){if(!y.isDir(e.mode))return 54;if(y.isRoot(e)||y.Ra(e)===y.cwd())return 10}else if(y.isDir(e.mode))return 31;return 0},Lc:(a,b)=>a?y.Ya(a.mode)?32:y.isDir(a.mode)&&("r"!==y.Ub(b)||b&512)?31:y.Ta(a,y.Ub(b)):44,ic:4096,Pc:(a=0,b=y.ic)=>{for(;a<=b;a++)if(!y.streams[a])return a;throw new y.ErrnoError(33);},Sa:a=>y.streams[a],Ac:(a,b,c)=>{y.nb||(y.nb=function(){},y.nb.prototype={object:{get:function(){return this.node},set:function(e){this.node=e}}});
a=Object.assign(new y.nb,a);b=y.Pc(b,c);a.fd=b;return y.streams[b]=a},uc:a=>{y.streams[a]=null},tc:{open:a=>{a.stream_ops=y.Gc(a.node.rdev).stream_ops;a.stream_ops.open&&a.stream_ops.open(a)},llseek:()=>{throw new y.ErrnoError(70);}},Cb:a=>a>>8,gd:a=>a&255,Va:(a,b)=>a<<8|b,Ib:(a,b)=>{y.Rb[a]={stream_ops:b}},Gc:a=>y.Rb[a],Wb:a=>{var b=[];for(a=[a];a.length;){var c=a.pop();b.push(c);a.push.apply(a,c.eb)}return b},fc:(a,b)=>{function c(k){y.mb--;return b(k)}function e(k){if(k){if(!e.Bc)return e.Bc=!0,
c(k)}else++g>=f.length&&c(null)}"function"==typeof a&&(b=a,a=!1);y.mb++;1<y.mb&&M("warning: "+y.mb+" FS.syncfs operations in flight at once, probably just doing extra work");var f=y.Wb(y.root.mount),g=0;f.forEach(k=>{if(!k.type.fc)return e(null);k.type.fc(k,a,e)})},mount:(a,b,c)=>{var e="/"===c,f=!c;if(e&&y.root)throw new y.ErrnoError(10);if(!e&&!f){var g=y.lookupPath(c,{ub:!1});c=g.path;g=g.node;if(y.Ua(g))throw new y.ErrnoError(10);if(!y.isDir(g.mode))throw new y.ErrnoError(54);}b={type:a,kd:b,
dc:c,eb:[]};a=a.mount(b);a.mount=b;b.root=a;e?y.root=a:g&&(g.cb=b,g.mount&&g.mount.eb.push(b));return a},nd:a=>{a=y.lookupPath(a,{ub:!1});if(!y.Ua(a.node))throw new y.ErrnoError(28);a=a.node;var b=a.cb,c=y.Wb(b);Object.keys(y.Na).forEach(e=>{for(e=y.Na[e];e;){var f=e.Wa;c.includes(e.mount)&&y.sb(e);e=f}});a.cb=null;a.mount.eb.splice(a.mount.eb.indexOf(b),1)},lookup:(a,b)=>a.node_ops.lookup(a,b),mknod:(a,b,c)=>{var e=y.lookupPath(a,{parent:!0}).node;a=V(a);if(!a||"."===a||".."===a)throw new y.ErrnoError(28);
var f=y.Db(e,a);if(f)throw new y.ErrnoError(f);if(!e.node_ops.mknod)throw new y.ErrnoError(63);return e.node_ops.mknod(e,a,b,c)},create:(a,b)=>y.mknod(a,(void 0!==b?b:438)&4095|32768,0),mkdir:(a,b)=>y.mknod(a,(void 0!==b?b:511)&1023|16384,0),hd:(a,b)=>{a=a.split("/");for(var c="",e=0;e<a.length;++e)if(a[e]){c+="/"+a[e];try{y.mkdir(c,b)}catch(f){if(20!=f.Ia)throw f;}}},kb:(a,b,c)=>{"undefined"==typeof c&&(c=b,b=438);return y.mknod(a,b|8192,c)},symlink:(a,b)=>{if(!lb(a))throw new y.ErrnoError(44);var c=
y.lookupPath(b,{parent:!0}).node;if(!c)throw new y.ErrnoError(44);b=V(b);var e=y.Db(c,b);if(e)throw new y.ErrnoError(e);if(!c.node_ops.symlink)throw new y.ErrnoError(63);return c.node_ops.symlink(c,b,a)},rename:(a,b)=>{var c=ib(a),e=ib(b),f=V(a),g=V(b);var k=y.lookupPath(a,{parent:!0});var l=k.node;k=y.lookupPath(b,{parent:!0});k=k.node;if(!l||!k)throw new y.ErrnoError(44);if(l.mount!==k.mount)throw new y.ErrnoError(75);var q=y.lookupNode(l,f);a=mb(a,e);if("."!==a.charAt(0))throw new y.ErrnoError(28);
a=mb(b,c);if("."!==a.charAt(0))throw new y.ErrnoError(55);try{var n=y.lookupNode(k,g)}catch(r){}if(q!==n){b=y.isDir(q.mode);if(f=y.jb(l,f,b))throw new y.ErrnoError(f);if(f=n?y.jb(k,g,b):y.Db(k,g))throw new y.ErrnoError(f);if(!l.node_ops.rename)throw new y.ErrnoError(63);if(y.Ua(q)||n&&y.Ua(n))throw new y.ErrnoError(10);if(k!==l&&(f=y.Ta(l,"w")))throw new y.ErrnoError(f);y.ac(q);try{l.node_ops.rename(q,k,g)}catch(r){throw r;}finally{y.$b(q)}}},rmdir:a=>{var b=y.lookupPath(a,{parent:!0}).node;a=V(a);
var c=y.lookupNode(b,a),e=y.jb(b,a,!0);if(e)throw new y.ErrnoError(e);if(!b.node_ops.rmdir)throw new y.ErrnoError(63);if(y.Ua(c))throw new y.ErrnoError(10);b.node_ops.rmdir(b,a);y.sb(c)},readdir:a=>{a=y.lookupPath(a,{Ma:!0}).node;if(!a.node_ops.readdir)throw new y.ErrnoError(54);return a.node_ops.readdir(a)},unlink:a=>{var b=y.lookupPath(a,{parent:!0}).node;if(!b)throw new y.ErrnoError(44);a=V(a);var c=y.lookupNode(b,a),e=y.jb(b,a,!1);if(e)throw new y.ErrnoError(e);if(!b.node_ops.unlink)throw new y.ErrnoError(63);
if(y.Ua(c))throw new y.ErrnoError(10);b.node_ops.unlink(b,a);y.sb(c)},readlink:a=>{a=y.lookupPath(a).node;if(!a)throw new y.ErrnoError(44);if(!a.node_ops.readlink)throw new y.ErrnoError(28);return lb(y.Ra(a.parent),a.node_ops.readlink(a))},stat:(a,b)=>{a=y.lookupPath(a,{Ma:!b}).node;if(!a)throw new y.ErrnoError(44);if(!a.node_ops.getattr)throw new y.ErrnoError(63);return a.node_ops.getattr(a)},lstat:a=>y.stat(a,!0),chmod:(a,b,c)=>{a="string"==typeof a?y.lookupPath(a,{Ma:!c}).node:a;if(!a.node_ops.setattr)throw new y.ErrnoError(63);
a.node_ops.setattr(a,{mode:b&4095|a.mode&-4096,timestamp:Date.now()})},lchmod:(a,b)=>{y.chmod(a,b,!0)},fchmod:(a,b)=>{a=y.Sa(a);if(!a)throw new y.ErrnoError(8);y.chmod(a.node,b)},chown:(a,b,c,e)=>{a="string"==typeof a?y.lookupPath(a,{Ma:!e}).node:a;if(!a.node_ops.setattr)throw new y.ErrnoError(63);a.node_ops.setattr(a,{timestamp:Date.now()})},lchown:(a,b,c)=>{y.chown(a,b,c,!0)},fchown:(a,b,c)=>{a=y.Sa(a);if(!a)throw new y.ErrnoError(8);y.chown(a.node,b,c)},truncate:(a,b)=>{if(0>b)throw new y.ErrnoError(28);
a="string"==typeof a?y.lookupPath(a,{Ma:!0}).node:a;if(!a.node_ops.setattr)throw new y.ErrnoError(63);if(y.isDir(a.mode))throw new y.ErrnoError(31);if(!y.isFile(a.mode))throw new y.ErrnoError(28);var c=y.Ta(a,"w");if(c)throw new y.ErrnoError(c);a.node_ops.setattr(a,{size:b,timestamp:Date.now()})},Ec:(a,b)=>{a=y.Sa(a);if(!a)throw new y.ErrnoError(8);if(0===(a.flags&2097155))throw new y.ErrnoError(28);y.truncate(a.node,b)},Xc:(a,b,c)=>{a=y.lookupPath(a,{Ma:!0}).node;a.node_ops.setattr(a,{timestamp:Math.max(b,
c)})},open:(a,b,c,e,f)=>{if(""===a)throw new y.ErrnoError(44);b="string"==typeof b?y.Nc(b):b;c=b&64?("undefined"==typeof c?438:c)&4095|32768:0;if("object"==typeof a)var g=a;else{a=hb(a);try{g=y.lookupPath(a,{Ma:!(b&131072)}).node}catch(l){}}var k=!1;if(b&64)if(g){if(b&128)throw new y.ErrnoError(20);}else g=y.mknod(a,c,0),k=!0;if(!g)throw new y.ErrnoError(44);y.ib(g.mode)&&(b&=-513);if(b&65536&&!y.isDir(g.mode))throw new y.ErrnoError(54);if(!k&&(c=y.Lc(g,b)))throw new y.ErrnoError(c);b&512&&y.truncate(g,
0);b&=-131713;e=y.Ac({node:g,path:y.Ra(g),flags:b,seekable:!0,position:0,stream_ops:g.stream_ops,Wc:[],error:!1},e,f);e.stream_ops.open&&e.stream_ops.open(e);!Module.logReadFiles||b&1||(y.Gb||(y.Gb={}),a in y.Gb||(y.Gb[a]=1));return e},close:a=>{if(y.bb(a))throw new y.ErrnoError(8);a.xb&&(a.xb=null);try{a.stream_ops.close&&a.stream_ops.close(a)}catch(b){throw b;}finally{y.uc(a.fd)}a.fd=null},bb:a=>null===a.fd,llseek:(a,b,c)=>{if(y.bb(a))throw new y.ErrnoError(8);if(!a.seekable||!a.stream_ops.llseek)throw new y.ErrnoError(70);
if(0!=c&&1!=c&&2!=c)throw new y.ErrnoError(28);a.position=a.stream_ops.llseek(a,b,c);a.Wc=[];return a.position},read:(a,b,c,e,f)=>{if(0>e||0>f)throw new y.ErrnoError(28);if(y.bb(a))throw new y.ErrnoError(8);if(1===(a.flags&2097155))throw new y.ErrnoError(8);if(y.isDir(a.node.mode))throw new y.ErrnoError(31);if(!a.stream_ops.read)throw new y.ErrnoError(28);var g="undefined"!=typeof f;if(!g)f=a.position;else if(!a.seekable)throw new y.ErrnoError(70);b=a.stream_ops.read(a,b,c,e,f);g||(a.position+=b);
return b},write:(a,b,c,e,f,g)=>{if(0>e||0>f)throw new y.ErrnoError(28);if(y.bb(a))throw new y.ErrnoError(8);if(0===(a.flags&2097155))throw new y.ErrnoError(8);if(y.isDir(a.node.mode))throw new y.ErrnoError(31);if(!a.stream_ops.write)throw new y.ErrnoError(28);a.seekable&&a.flags&1024&&y.llseek(a,0,2);var k="undefined"!=typeof f;if(!k)f=a.position;else if(!a.seekable)throw new y.ErrnoError(70);b=a.stream_ops.write(a,b,c,e,f,g);k||(a.position+=b);return b},allocate:(a,b,c)=>{if(y.bb(a))throw new y.ErrnoError(8);
if(0>b||0>=c)throw new y.ErrnoError(28);if(0===(a.flags&2097155))throw new y.ErrnoError(8);if(!y.isFile(a.node.mode)&&!y.isDir(a.node.mode))throw new y.ErrnoError(43);if(!a.stream_ops.allocate)throw new y.ErrnoError(138);a.stream_ops.allocate(a,b,c)},mmap:(a,b,c,e,f,g)=>{if(0!==(f&2)&&0===(g&2)&&2!==(a.flags&2097155))throw new y.ErrnoError(2);if(1===(a.flags&2097155))throw new y.ErrnoError(2);if(!a.stream_ops.mmap)throw new y.ErrnoError(43);return a.stream_ops.mmap(a,b,c,e,f,g)},msync:(a,b,c,e,f)=>
a&&a.stream_ops.msync?a.stream_ops.msync(a,b,c,e,f):0,jd:()=>0,cc:(a,b,c)=>{if(!a.stream_ops.cc)throw new y.ErrnoError(59);return a.stream_ops.cc(a,b,c)},readFile:(a,b={})=>{b.flags=b.flags||0;b.encoding=b.encoding||"binary";if("utf8"!==b.encoding&&"binary"!==b.encoding)throw Error('Invalid encoding type "'+b.encoding+'"');var c,e=y.open(a,b.flags);a=y.stat(a).size;var f=new Uint8Array(a);y.read(e,f,0,a,0);"utf8"===b.encoding?c=La(f,0):"binary"===b.encoding&&(c=f);y.close(e);return c},writeFile:(a,
b,c={})=>{c.flags=c.flags||577;a=y.open(a,c.flags,c.mode);if("string"==typeof b){var e=new Uint8Array(d(b)+1);b=p(b,e,0,e.length);y.write(a,e,0,b,void 0,c.sc)}else if(ArrayBuffer.isView(b))y.write(a,b,0,b.byteLength,void 0,c.sc);else throw Error("Unsupported data type");y.close(a)},cwd:()=>y.Qb,chdir:a=>{a=y.lookupPath(a,{Ma:!0});if(null===a.node)throw new y.ErrnoError(44);if(!y.isDir(a.node.mode))throw new y.ErrnoError(54);var b=y.Ta(a.node,"x");if(b)throw new y.ErrnoError(b);y.Qb=a.path},wc:()=>
{y.mkdir("/tmp");y.mkdir("/home");y.mkdir("/home/web_user")},vc:()=>{y.mkdir("/dev");y.Ib(y.Va(1,3),{read:()=>0,write:(b,c,e,f)=>f});y.kb("/dev/null",y.Va(1,3));ob(y.Va(5,0),qb);ob(y.Va(6,0),rb);y.kb("/dev/tty",y.Va(5,0));y.kb("/dev/tty1",y.Va(6,0));var a=kb();y.Pa("/dev","random",a);y.Pa("/dev","urandom",a);y.mkdir("/dev/shm");y.mkdir("/dev/shm/tmp")},yc:()=>{y.mkdir("/proc");var a=y.mkdir("/proc/self");y.mkdir("/proc/self/fd");y.mount({mount:()=>{var b=y.createNode(a,"fd",16895,73);b.node_ops={lookup:(c,
e)=>{var f=y.Sa(+e);if(!f)throw new y.ErrnoError(8);c={parent:null,mount:{dc:"fake"},node_ops:{readlink:()=>f.path}};return c.parent=c}};return b}},{},"/proc/self/fd")},zc:()=>{Module.stdin?y.Pa("/dev","stdin",Module.stdin):y.symlink("/dev/tty","/dev/stdin");Module.stdout?y.Pa("/dev","stdout",null,Module.stdout):y.symlink("/dev/tty","/dev/stdout");Module.stderr?y.Pa("/dev","stderr",null,Module.stderr):y.symlink("/dev/tty1","/dev/stderr");y.open("/dev/stdin",0);y.open("/dev/stdout",1);y.open("/dev/stderr",
1)},Sb:()=>{y.ErrnoError||(y.ErrnoError=function(a,b){this.node=b;this.Vc=function(c){this.Ia=c};this.Vc(a);this.message="FS error"},y.ErrnoError.prototype=Error(),y.ErrnoError.prototype.constructor=y.ErrnoError,[44].forEach(a=>{y.vb[a]=new y.ErrnoError(a);y.vb[a].stack="<generic error, no stack>"}))},ec:()=>{y.Sb();y.Na=Array(4096);y.mount(W,{},"/");y.wc();y.vc();y.yc();y.Cc={MEMFS:W}},hb:(a,b,c)=>{y.hb.zb=!0;y.Sb();Module.stdin=a||Module.stdin;Module.stdout=b||Module.stdout;Module.stderr=c||Module.stderr;
y.zc()},ld:()=>{y.hb.zb=!1;for(var a=0;a<y.streams.length;a++){var b=y.streams[a];b&&y.close(b)}},wb:(a,b)=>{var c=0;a&&(c|=365);b&&(c|=146);return c},ad:(a,b)=>{a=y.pb(a,b);return a.exists?a.object:null},pb:(a,b)=>{try{var c=y.lookupPath(a,{Ma:!b});a=c.path}catch(f){}var e={isRoot:!1,exists:!1,error:0,name:null,path:null,object:null,Qc:!1,Sc:null,Rc:null};try{c=y.lookupPath(a,{parent:!0}),e.Qc=!0,e.Sc=c.path,e.Rc=c.node,e.name=V(a),c=y.lookupPath(a,{Ma:!b}),e.exists=!0,e.path=c.path,e.object=c.node,
e.name=c.node.name,e.isRoot="/"===c.path}catch(f){e.error=f.Ia}return e},Zc:(a,b)=>{a="string"==typeof a?a:y.Ra(a);for(b=b.split("/").reverse();b.length;){var c=b.pop();if(c){var e=jb(a,c);try{y.mkdir(e)}catch(f){}a=e}}return e},xc:(a,b,c,e,f)=>{a=jb("string"==typeof a?a:y.Ra(a),b);return y.create(a,y.wb(e,f))},rb:(a,b,c,e,f,g)=>{var k=b;a&&(a="string"==typeof a?a:y.Ra(a),k=b?jb(a,b):a);a=y.wb(e,f);k=y.create(k,a);if(c){if("string"==typeof c){b=Array(c.length);e=0;for(f=c.length;e<f;++e)b[e]=c.charCodeAt(e);
c=b}y.chmod(k,a|146);b=y.open(k,577);y.write(b,c,0,c.length,0,g);y.close(b);y.chmod(k,a)}return k},Pa:(a,b,c,e)=>{a=jb("string"==typeof a?a:y.Ra(a),b);b=y.wb(!!c,!!e);y.Pa.Cb||(y.Pa.Cb=64);var f=y.Va(y.Pa.Cb++,0);y.Ib(f,{open:g=>{g.seekable=!1},close:()=>{e&&e.buffer&&e.buffer.length&&e(10)},read:(g,k,l,q)=>{for(var n=0,r=0;r<q;r++){try{var x=c()}catch(z){throw new y.ErrnoError(29);}if(void 0===x&&0===n)throw new y.ErrnoError(6);if(null===x||void 0===x)break;n++;k[l+r]=x}n&&(g.node.timestamp=Date.now());
return n},write:(g,k,l,q)=>{for(var n=0;n<q;n++)try{e(k[l+n])}catch(r){throw new y.ErrnoError(29);}q&&(g.node.timestamp=Date.now());return n}});return y.kb(a,b,f)},Vb:a=>{if(a.Ab||a.Jc||a.link||a.Ha)return!0;if("undefined"!=typeof XMLHttpRequest)throw Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");if(ra)try{a.Ha=ba(ra(a.url),!0),a.La=a.Ha.length}catch(b){throw new y.ErrnoError(29);
}else throw Error("Cannot load without read() or XMLHttpRequest.");},Yc:(a,b,c,e,f)=>{function g(){this.Bb=!1;this.gb=[]}g.prototype.get=function(n){if(!(n>this.length-1||0>n)){var r=n%this.chunkSize;return this.Zb(n/this.chunkSize|0)[r]}};g.prototype.hc=function(n){this.Zb=n};g.prototype.Ob=function(){var n=new XMLHttpRequest;n.open("HEAD",c,!1);n.send(null);if(!(200<=n.status&&300>n.status||304===n.status))throw Error("Couldn't load "+c+". Status: "+n.status);var r=Number(n.getResponseHeader("Content-length")),
x,z=(x=n.getResponseHeader("Accept-Ranges"))&&"bytes"===x;n=(x=n.getResponseHeader("Content-Encoding"))&&"gzip"===x;var D=1048576;z||(D=r);var A=this;A.hc(S=>{var Y=S*D,T=(S+1)*D-1;T=Math.min(T,r-1);if("undefined"==typeof A.gb[S]){var Ia=A.gb;if(Y>T)throw Error("invalid range ("+Y+", "+T+") or no bytes requested!");if(T>r-1)throw Error("only "+r+" bytes available! programmer error!");var E=new XMLHttpRequest;E.open("GET",c,!1);r!==D&&E.setRequestHeader("Range","bytes="+Y+"-"+T);E.responseType="arraybuffer";
E.overrideMimeType&&E.overrideMimeType("text/plain; charset=x-user-defined");E.send(null);if(!(200<=E.status&&300>E.status||304===E.status))throw Error("Couldn't load "+c+". Status: "+E.status);Y=void 0!==E.response?new Uint8Array(E.response||[]):ba(E.responseText||"",!0);Ia[S]=Y}if("undefined"==typeof A.gb[S])throw Error("doXHR failed!");return A.gb[S]});if(n||!r)D=r=1,D=r=this.Zb(0).length,xa("LazyFiles on gzip forces download of the whole file when length is accessed");this.kc=r;this.jc=D;this.Bb=
!0};if("undefined"!=typeof XMLHttpRequest){if(!pa)throw"Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc";var k=new g;Object.defineProperties(k,{length:{get:function(){this.Bb||this.Ob();return this.kc}},chunkSize:{get:function(){this.Bb||this.Ob();return this.jc}}});k={Ab:!1,Ha:k}}else k={Ab:!1,url:c};var l=y.xc(a,b,k,e,f);k.Ha?l.Ha=k.Ha:k.url&&(l.Ha=null,l.url=k.url);Object.defineProperties(l,{La:{get:function(){return this.Ha.length}}});
var q={};Object.keys(l.stream_ops).forEach(n=>{var r=l.stream_ops[n];q[n]=function(){y.Vb(l);return r.apply(null,arguments)}});q.read=(n,r,x,z,D)=>{y.Vb(l);n=n.node.Ha;if(D>=n.length)return 0;z=Math.min(n.length-D,z);if(n.slice)for(var A=0;A<z;A++)r[x+A]=n[D+A];else for(A=0;A<z;A++)r[x+A]=n.get(D+A);return z};l.stream_ops=q;return l},$c:(a,b,c,e,f,g,k,l,q,n)=>{function r(z){function D(A){n&&n();l||y.rb(a,b,A,e,f,q);g&&g();Xa()}ub.dd(z,x,D,()=>{k&&k();Xa()})||D(z)}var x=b?lb(jb(a,b)):a;Wa();"string"==
typeof c?tb(c,z=>r(z),k):r(c)},indexedDB:()=>window.indexedDB||window.mozIndexedDB||window.webkitIndexedDB||window.msIndexedDB,Jb:()=>"EM_FS_"+window.location.pathname,Kb:20,ab:"FILE_DATA",md:(a,b,c)=>{b=b||(()=>{});c=c||(()=>{});var e=y.indexedDB();try{var f=e.open(y.Jb(),y.Kb)}catch(g){return c(g)}f.onupgradeneeded=()=>{xa("creating db");f.result.createObjectStore(y.ab)};f.onsuccess=()=>{var g=f.result.transaction([y.ab],"readwrite"),k=g.objectStore(y.ab),l=0,q=0,n=a.length;a.forEach(r=>{r=k.put(y.pb(r).object.Ha,
r);r.onsuccess=()=>{l++;l+q==n&&(0==q?b():c())};r.onerror=()=>{q++;l+q==n&&(0==q?b():c())}});g.onerror=c};f.onerror=c},ed:(a,b,c)=>{b=b||(()=>{});c=c||(()=>{});var e=y.indexedDB();try{var f=e.open(y.Jb(),y.Kb)}catch(g){return c(g)}f.onupgradeneeded=c;f.onsuccess=()=>{var g=f.result;try{var k=g.transaction([y.ab],"readonly")}catch(x){c(x);return}var l=k.objectStore(y.ab),q=0,n=0,r=a.length;a.forEach(x=>{var z=l.get(x);z.onsuccess=()=>{y.pb(x).exists&&y.unlink(x);y.rb(ib(x),V(x),z.result,!0,!0,!0);
q++;q+n==r&&(0==n?b():c())};z.onerror=()=>{n++;q+n==r&&(0==n?b():c())}});k.onerror=c};f.onerror=c}};function vb(a,b,c){if("/"===b[0])return b;if(-100===a)a=y.cwd();else{a=y.Sa(a);if(!a)throw new y.ErrnoError(8);a=a.path}if(0==b.length){if(!c)throw new y.ErrnoError(44);return a}return jb(a,b)}
function wb(a,b,c){try{var e=a(b)}catch(f){if(f&&f.node&&hb(b)!==hb(y.Ra(f.node)))return-54;throw f;}P[c>>2]=e.dev;P[c+4>>2]=0;P[c+8>>2]=e.ino;P[c+12>>2]=e.mode;P[c+16>>2]=e.nlink;P[c+20>>2]=e.uid;P[c+24>>2]=e.gid;P[c+28>>2]=e.rdev;P[c+32>>2]=0;Q=[e.size>>>0,(R=e.size,1<=+Math.abs(R)?0<R?(Math.min(+Math.floor(R/4294967296),4294967295)|0)>>>0:~~+Math.ceil((R-+(~~R>>>0))/4294967296)>>>0:0)];P[c+40>>2]=Q[0];P[c+44>>2]=Q[1];P[c+48>>2]=4096;P[c+52>>2]=e.blocks;P[c+56>>2]=e.atime.getTime()/1E3|0;P[c+60>>
2]=0;P[c+64>>2]=e.mtime.getTime()/1E3|0;P[c+68>>2]=0;P[c+72>>2]=e.ctime.getTime()/1E3|0;P[c+76>>2]=0;Q=[e.ino>>>0,(R=e.ino,1<=+Math.abs(R)?0<R?(Math.min(+Math.floor(R/4294967296),4294967295)|0)>>>0:~~+Math.ceil((R-+(~~R>>>0))/4294967296)>>>0:0)];P[c+80>>2]=Q[0];P[c+84>>2]=Q[1];return 0}var Tb=void 0;function Ub(){Tb+=4;return P[Tb-4>>2]}function X(a){a=y.Sa(a);if(!a)throw new y.ErrnoError(8);return a}
function Vb(a,b,c){function e(q){return(q=q.toTimeString().match(/\(([A-Za-z ]+)\)$/))?q[1]:"GMT"}var f=(new Date).getFullYear(),g=new Date(f,0,1),k=new Date(f,6,1);f=g.getTimezoneOffset();var l=k.getTimezoneOffset();P[a>>2]=60*Math.max(f,l);P[b>>2]=Number(f!=l);a=e(g);b=e(k);a=Ma(a);b=Ma(b);l<f?(P[c>>2]=a,P[c+4>>2]=b):(P[c>>2]=b,P[c+4>>2]=a)}function Wb(a,b,c){Wb.rc||(Wb.rc=!0,Vb(a,b,c))}var Xb;Xb=qa?()=>{var a=process.hrtime();return 1E3*a[0]+a[1]/1E6}:()=>performance.now();var Yb={};
function Zb(){if(!$b){var a={USER:"web_user",LOGNAME:"web_user",PATH:"/",PWD:"/",HOME:"/home/web_user",LANG:("object"==typeof navigator&&navigator.languages&&navigator.languages[0]||"C").replace("-","_")+".UTF-8",_:ma||"./this.program"},b;for(b in Yb)void 0===Yb[b]?delete a[b]:a[b]=Yb[b];var c=[];for(b in a)c.push(b+"="+a[b]);$b=c}return $b}var $b;
function ac(a,b,c,e){a||(a=this);this.parent=a;this.mount=a.mount;this.cb=null;this.id=y.Oc++;this.name=b;this.mode=c;this.node_ops={};this.stream_ops={};this.rdev=e}Object.defineProperties(ac.prototype,{read:{get:function(){return 365===(this.mode&365)},set:function(a){a?this.mode|=365:this.mode&=-366}},write:{get:function(){return 146===(this.mode&146)},set:function(a){a?this.mode|=146:this.mode&=-147}},Jc:{get:function(){return y.isDir(this.mode)}},Ab:{get:function(){return y.ib(this.mode)}}});
y.FSNode=ac;y.ec();var ub;function ba(a,b){var c=Array(d(a)+1);a=p(a,c,0,c.length);b&&(c.length=a);return c}
var cc={a:function(a,b,c,e){O("Assertion failed: "+J(a)+", at: "+[b?J(b):"unknown filename",c,e?J(e):"unknown function"])},h:function(a,b){try{return a=J(a),y.chmod(a,b),0}catch(c){if("undefined"==typeof y||!(c instanceof y.ErrnoError))throw c;return-c.Ia}},H:function(a,b,c){try{b=J(b);b=vb(a,b);if(c&-8)var e=-28;else{var f=y.lookupPath(b,{Ma:!0}).node;f?(a="",c&4&&(a+="r"),c&2&&(a+="w"),c&1&&(a+="x"),e=a&&y.Ta(f,a)?-2:0):e=-44}return e}catch(g){if("undefined"==typeof y||!(g instanceof y.ErrnoError))throw g;
return-g.Ia}},i:function(a,b){try{return y.fchmod(a,b),0}catch(c){if("undefined"==typeof y||!(c instanceof y.ErrnoError))throw c;return-c.Ia}},g:function(a,b,c){try{return y.fchown(a,b,c),0}catch(e){if("undefined"==typeof y||!(e instanceof y.ErrnoError))throw e;return-e.Ia}},b:function(a,b,c){Tb=c;try{var e=X(a);switch(b){case 0:var f=Ub();return 0>f?-28:y.open(e.path,e.flags,0,f).fd;case 1:case 2:return 0;case 3:return e.flags;case 4:return f=Ub(),e.flags|=f,0;case 5:return f=Ub(),Ba[f+0>>1]=2,0;
case 6:case 7:return 0;case 16:case 8:return-28;case 9:return P[bc()>>2]=28,-1;default:return-28}}catch(g){if("undefined"==typeof y||!(g instanceof y.ErrnoError))throw g;return-g.Ia}},G:function(a,b){try{var c=X(a);return wb(y.stat,c.path,b)}catch(e){if("undefined"==typeof y||!(e instanceof y.ErrnoError))throw e;return-e.Ia}},B:function(a,b){try{return y.Ec(a,b),0}catch(c){if("undefined"==typeof y||!(c instanceof y.ErrnoError))throw c;return-c.Ia}},A:function(a,b){try{if(0===b)return-28;var c=y.cwd();
if(b<d(c)+1)return-68;p(c,t,a,b);return a}catch(e){if("undefined"==typeof y||!(e instanceof y.ErrnoError))throw e;return-e.Ia}},E:function(a,b){try{return a=J(a),wb(y.lstat,a,b)}catch(c){if("undefined"==typeof y||!(c instanceof y.ErrnoError))throw c;return-c.Ia}},x:function(a,b){try{return a=J(a),a=hb(a),"/"===a[a.length-1]&&(a=a.substr(0,a.length-1)),y.mkdir(a,b,0),0}catch(c){if("undefined"==typeof y||!(c instanceof y.ErrnoError))throw c;return-c.Ia}},D:function(a,b,c,e){try{b=J(b);var f=e&256;b=
vb(a,b,e&4096);return wb(f?y.lstat:y.stat,b,c)}catch(g){if("undefined"==typeof y||!(g instanceof y.ErrnoError))throw g;return-g.Ia}},u:function(a,b,c,e){Tb=e;try{b=J(b);b=vb(a,b);var f=e?Ub():0;return y.open(b,c,f).fd}catch(g){if("undefined"==typeof y||!(g instanceof y.ErrnoError))throw g;return-g.Ia}},s:function(a,b,c,e){try{b=J(b);b=vb(a,b);if(0>=e)var f=-28;else{var g=y.readlink(b),k=Math.min(e,d(g)),l=I[c+k];p(g,t,c,e+1);I[c+k]=l;f=k}return f}catch(q){if("undefined"==typeof y||!(q instanceof y.ErrnoError))throw q;
return-q.Ia}},r:function(a){try{return a=J(a),y.rmdir(a),0}catch(b){if("undefined"==typeof y||!(b instanceof y.ErrnoError))throw b;return-b.Ia}},F:function(a,b){try{return a=J(a),wb(y.stat,a,b)}catch(c){if("undefined"==typeof y||!(c instanceof y.ErrnoError))throw c;return-c.Ia}},o:function(a,b,c){try{return b=J(b),b=vb(a,b),0===c?y.unlink(b):512===c?y.rmdir(b):O("Invalid flags passed to unlinkat"),0}catch(e){if("undefined"==typeof y||!(e instanceof y.ErrnoError))throw e;return-e.Ia}},m:function(a,
b,c){try{b=J(b);b=vb(a,b,!0);if(c){var e=P[c>>2],f=P[c+4>>2];g=1E3*e+f/1E6;c+=8;e=P[c>>2];f=P[c+4>>2];k=1E3*e+f/1E6}else var g=Date.now(),k=g;y.Xc(b,g,k);return 0}catch(l){if("undefined"==typeof y||!(l instanceof y.ErrnoError))throw l;return-l.Ia}},e:function(){return Date.now()},j:function(a,b){a=new Date(1E3*P[a>>2]);P[b>>2]=a.getSeconds();P[b+4>>2]=a.getMinutes();P[b+8>>2]=a.getHours();P[b+12>>2]=a.getDate();P[b+16>>2]=a.getMonth();P[b+20>>2]=a.getFullYear()-1900;P[b+24>>2]=a.getDay();var c=new Date(a.getFullYear(),
0,1);P[b+28>>2]=(a.getTime()-c.getTime())/864E5|0;P[b+36>>2]=-(60*a.getTimezoneOffset());var e=(new Date(a.getFullYear(),6,1)).getTimezoneOffset();c=c.getTimezoneOffset();P[b+32>>2]=(e!=c&&a.getTimezoneOffset()==Math.min(c,e))|0},v:function(a,b,c,e,f,g,k){try{var l=y.Sa(f);if(!l)return-8;var q=y.mmap(l,a,b,g,c,e),n=q.Tc;P[k>>2]=q.lc;return n}catch(r){if("undefined"==typeof y||!(r instanceof y.ErrnoError))throw r;return-r.Ia}},w:function(a,b,c,e,f,g){try{var k=y.Sa(f);if(k&&c&2){var l=t.slice(a,a+
b);y.msync(k,l,g,b,e)}}catch(q){if("undefined"==typeof y||!(q instanceof y.ErrnoError))throw q;return-q.Ia}},n:Wb,p:function(){return 2147483648},d:Xb,c:function(a){var b=t.length;a>>>=0;if(2147483648<a)return!1;for(var c=1;4>=c;c*=2){var e=b*(1+.2/c);e=Math.min(e,a+100663296);var f=Math;e=Math.max(a,e);f=f.min.call(f,2147483648,e+(65536-e%65536)%65536);a:{try{Ea.grow(f-Na.byteLength+65535>>>16);Oa();var g=1;break a}catch(k){}g=void 0}if(g)return!0}return!1},y:function(a,b){var c=0;Zb().forEach(function(e,
f){var g=b+c;f=P[a+4*f>>2]=g;for(g=0;g<e.length;++g)I[f++>>0]=e.charCodeAt(g);I[f>>0]=0;c+=e.length+1});return 0},z:function(a,b){var c=Zb();P[a>>2]=c.length;var e=0;c.forEach(function(f){e+=f.length+1});P[b>>2]=e;return 0},f:function(a){try{var b=X(a);y.close(b);return 0}catch(c){if("undefined"==typeof y||!(c instanceof y.ErrnoError))throw c;return c.Ia}},l:function(a,b){try{var c=X(a),e=c.tty?2:y.isDir(c.mode)?3:y.Ya(c.mode)?7:4;I[b>>0]=e;return 0}catch(f){if("undefined"==typeof y||!(f instanceof
y.ErrnoError))throw f;return f.Ia}},t:function(a,b,c,e){try{a:{for(var f=X(a),g=a=0;g<c;g++){var k=P[b+(8*g+4)>>2],l=y.read(f,I,P[b+8*g>>2],k,void 0);if(0>l){var q=-1;break a}a+=l;if(l<k)break}q=a}P[e>>2]=q;return 0}catch(n){if("undefined"==typeof y||!(n instanceof y.ErrnoError))throw n;return n.Ia}},k:function(a,b,c,e,f){try{var g=X(a);a=4294967296*c+(b>>>0);if(-9007199254740992>=a||9007199254740992<=a)return-61;y.llseek(g,a,e);Q=[g.position>>>0,(R=g.position,1<=+Math.abs(R)?0<R?(Math.min(+Math.floor(R/
4294967296),4294967295)|0)>>>0:~~+Math.ceil((R-+(~~R>>>0))/4294967296)>>>0:0)];P[f>>2]=Q[0];P[f+4>>2]=Q[1];g.xb&&0===a&&0===e&&(g.xb=null);return 0}catch(k){if("undefined"==typeof y||!(k instanceof y.ErrnoError))throw k;return k.Ia}},C:function(a){try{var b=X(a);return b.stream_ops&&b.stream_ops.fsync?-b.stream_ops.fsync(b):0}catch(c){if("undefined"==typeof y||!(c instanceof y.ErrnoError))throw c;return c.Ia}},q:function(a,b,c,e){try{a:{for(var f=X(a),g=a=0;g<c;g++){var k=y.write(f,I,P[b+8*g>>2],
P[b+(8*g+4)>>2],void 0);if(0>k){var l=-1;break a}a+=k}l=a}P[e>>2]=l;return 0}catch(q){if("undefined"==typeof y||!(q instanceof y.ErrnoError))throw q;return q.Ia}}};
(function(){function a(f){Module.asm=f.exports;Ea=Module.asm.I;Oa();N=Module.asm.Aa;Qa.unshift(Module.asm.J);Xa()}function b(f){a(f.instance)}function c(f){return eb().then(function(g){return WebAssembly.instantiate(g,e)}).then(function(g){return g}).then(f,function(g){M("failed to asynchronously prepare wasm: "+g);O(g)})}var e={a:cc};Wa();if(Module.instantiateWasm)try{return Module.instantiateWasm(e,a)}catch(f){return M("Module.instantiateWasm callback failed with error: "+f),!1}(function(){return Aa||
"function"!=typeof WebAssembly.instantiateStreaming||Ya()||U.startsWith("file://")||"function"!=typeof fetch?c(b):fetch(U,{credentials:"same-origin"}).then(function(f){return WebAssembly.instantiateStreaming(f,e).then(b,function(g){M("wasm streaming compile failed: "+g);M("falling back to ArrayBuffer instantiation");return c(b)})})})();return{}})();Module.___wasm_call_ctors=function(){return(Module.___wasm_call_ctors=Module.asm.J).apply(null,arguments)};
Module._sqlite3_vfs_find=function(){return(Module._sqlite3_vfs_find=Module.asm.K).apply(null,arguments)};Module._sqlite3_free=function(){return(Module._sqlite3_free=Module.asm.L).apply(null,arguments)};Module._sqlite3_value_double=function(){return(Module._sqlite3_value_double=Module.asm.M).apply(null,arguments)};Module._sqlite3_value_text=function(){return(Module._sqlite3_value_text=Module.asm.N).apply(null,arguments)};
var bc=Module.___errno_location=function(){return(bc=Module.___errno_location=Module.asm.O).apply(null,arguments)};Module._sqlite3_prepare_v2=function(){return(Module._sqlite3_prepare_v2=Module.asm.P).apply(null,arguments)};Module._sqlite3_step=function(){return(Module._sqlite3_step=Module.asm.Q).apply(null,arguments)};Module._sqlite3_finalize=function(){return(Module._sqlite3_finalize=Module.asm.R).apply(null,arguments)};
Module._sqlite3_reset=function(){return(Module._sqlite3_reset=Module.asm.S).apply(null,arguments)};Module._sqlite3_value_int=function(){return(Module._sqlite3_value_int=Module.asm.T).apply(null,arguments)};Module._sqlite3_clear_bindings=function(){return(Module._sqlite3_clear_bindings=Module.asm.U).apply(null,arguments)};Module._sqlite3_value_blob=function(){return(Module._sqlite3_value_blob=Module.asm.V).apply(null,arguments)};
Module._sqlite3_value_bytes=function(){return(Module._sqlite3_value_bytes=Module.asm.W).apply(null,arguments)};Module._sqlite3_value_type=function(){return(Module._sqlite3_value_type=Module.asm.X).apply(null,arguments)};Module._sqlite3_result_blob=function(){return(Module._sqlite3_result_blob=Module.asm.Y).apply(null,arguments)};Module._sqlite3_result_double=function(){return(Module._sqlite3_result_double=Module.asm.Z).apply(null,arguments)};
Module._sqlite3_result_error=function(){return(Module._sqlite3_result_error=Module.asm._).apply(null,arguments)};Module._sqlite3_result_int=function(){return(Module._sqlite3_result_int=Module.asm.$).apply(null,arguments)};Module._sqlite3_result_int64=function(){return(Module._sqlite3_result_int64=Module.asm.aa).apply(null,arguments)};Module._sqlite3_result_null=function(){return(Module._sqlite3_result_null=Module.asm.ba).apply(null,arguments)};
Module._sqlite3_result_text=function(){return(Module._sqlite3_result_text=Module.asm.ca).apply(null,arguments)};Module._sqlite3_sql=function(){return(Module._sqlite3_sql=Module.asm.da).apply(null,arguments)};Module._sqlite3_column_count=function(){return(Module._sqlite3_column_count=Module.asm.ea).apply(null,arguments)};Module._sqlite3_data_count=function(){return(Module._sqlite3_data_count=Module.asm.fa).apply(null,arguments)};
Module._sqlite3_column_blob=function(){return(Module._sqlite3_column_blob=Module.asm.ga).apply(null,arguments)};Module._sqlite3_column_bytes=function(){return(Module._sqlite3_column_bytes=Module.asm.ha).apply(null,arguments)};Module._sqlite3_column_double=function(){return(Module._sqlite3_column_double=Module.asm.ia).apply(null,arguments)};Module._sqlite3_column_text=function(){return(Module._sqlite3_column_text=Module.asm.ja).apply(null,arguments)};
Module._sqlite3_column_type=function(){return(Module._sqlite3_column_type=Module.asm.ka).apply(null,arguments)};Module._sqlite3_column_name=function(){return(Module._sqlite3_column_name=Module.asm.la).apply(null,arguments)};Module._sqlite3_bind_blob=function(){return(Module._sqlite3_bind_blob=Module.asm.ma).apply(null,arguments)};Module._sqlite3_bind_double=function(){return(Module._sqlite3_bind_double=Module.asm.na).apply(null,arguments)};
Module._sqlite3_bind_int=function(){return(Module._sqlite3_bind_int=Module.asm.oa).apply(null,arguments)};Module._sqlite3_bind_text=function(){return(Module._sqlite3_bind_text=Module.asm.pa).apply(null,arguments)};Module._sqlite3_bind_parameter_index=function(){return(Module._sqlite3_bind_parameter_index=Module.asm.qa).apply(null,arguments)};Module._sqlite3_normalized_sql=function(){return(Module._sqlite3_normalized_sql=Module.asm.ra).apply(null,arguments)};
Module._sqlite3_errmsg=function(){return(Module._sqlite3_errmsg=Module.asm.sa).apply(null,arguments)};Module._sqlite3_exec=function(){return(Module._sqlite3_exec=Module.asm.ta).apply(null,arguments)};Module._sqlite3_changes=function(){return(Module._sqlite3_changes=Module.asm.ua).apply(null,arguments)};Module._sqlite3_close_v2=function(){return(Module._sqlite3_close_v2=Module.asm.va).apply(null,arguments)};
Module._sqlite3_create_function_v2=function(){return(Module._sqlite3_create_function_v2=Module.asm.wa).apply(null,arguments)};Module._sqlite3_open=function(){return(Module._sqlite3_open=Module.asm.xa).apply(null,arguments)};var aa=Module._malloc=function(){return(aa=Module._malloc=Module.asm.ya).apply(null,arguments)},da=Module._free=function(){return(da=Module._free=Module.asm.za).apply(null,arguments)};
Module._RegisterExtensionFunctions=function(){return(Module._RegisterExtensionFunctions=Module.asm.Ba).apply(null,arguments)};Module._register_for_idb=function(){return(Module._register_for_idb=Module.asm.Ca).apply(null,arguments)};
var sb=Module._emscripten_builtin_memalign=function(){return(sb=Module._emscripten_builtin_memalign=Module.asm.Da).apply(null,arguments)},fa=Module.stackSave=function(){return(fa=Module.stackSave=Module.asm.Ea).apply(null,arguments)},ia=Module.stackRestore=function(){return(ia=Module.stackRestore=Module.asm.Fa).apply(null,arguments)},C=Module.stackAlloc=function(){return(C=Module.stackAlloc=Module.asm.Ga).apply(null,arguments)};
Module.cwrap=function(a,b,c,e){c=c||[];var f=c.every(function(g){return"number"===g});return"string"!==b&&f&&!e?Module["_"+a]:function(){return Ga(a,b,c,arguments)}};Module.UTF8ToString=J;Module.FS=y;Module.stackSave=fa;Module.stackRestore=ia;Module.stackAlloc=C;var dc;Va=function ec(){dc||fc();dc||(Va=ec)};
function fc(){function a(){if(!dc&&(dc=!0,Module.calledRun=!0,!Fa)){Module.noFSInit||y.hb.zb||y.hb();y.bc=!1;fb(Qa);if(Module.onRuntimeInitialized)Module.onRuntimeInitialized();if(Module.postRun)for("function"==typeof Module.postRun&&(Module.postRun=[Module.postRun]);Module.postRun.length;){var b=Module.postRun.shift();Ra.unshift(b)}fb(Ra)}}if(!(0<Ta)){if(Module.preRun)for("function"==typeof Module.preRun&&(Module.preRun=[Module.preRun]);Module.preRun.length;)Sa();fb(Pa);0<Ta||(Module.setStatus?(Module.setStatus("Running..."),
setTimeout(function(){setTimeout(function(){Module.setStatus("")},1);a()},1)):a())}}Module.run=fc;if(Module.preInit)for("function"==typeof Module.preInit&&(Module.preInit=[Module.preInit]);0<Module.preInit.length;)Module.preInit.pop()();fc();


        // The shell-pre.js and emcc-generated code goes above
        return Module;
    }); // The end of the promise being returned

  return initSqlJsPromise;
} // The end of our initSqlJs function

// This bit below is copied almost exactly from what you get when you use the MODULARIZE=1 flag with emcc
// However, we don't want to use the emcc modularization. See shell-pre.js
if (typeof exports === 'object' && typeof module === 'object'){
    module.exports = initSqlJs;
    // This will allow the module to be used in ES6 or CommonJS
    module.exports.default = initSqlJs;
}
else if (typeof define === 'function' && define['amd']) {
    define([], function() { return initSqlJs; });
}
else if (typeof exports === 'object'){
    exports["Module"] = initSqlJs;
}
/* global initSqlJs */
/* eslint-env worker */
/* eslint no-restricted-globals: ["error"] */

"use strict";

var db;

function onModuleReady(SQL) {
    function createDb(data) {
        if (db != null) db.close();
        db = new SQL.Database(data);
        return db;
    }

    var buff; var data; var result;
    data = this["data"];
    var config = data["config"] ? data["config"] : {};
    switch (data && data["action"]) {
        case "open":
            buff = data["buffer"];
            createDb(buff && new Uint8Array(buff));
            return postMessage({
                id: data["id"],
                ready: true
            });
        case "exec":
            if (db === null) {
                createDb();
            }
            if (!data["sql"]) {
                throw "exec: Missing query string";
            }
            return postMessage({
                id: data["id"],
                results: db.exec(data["sql"], data["params"], config)
            });
        case "each":
            if (db === null) {
                createDb();
            }
            var callback = function callbackFn(row) {
                return postMessage({
                    id: data["id"],
                    row: row,
                    finished: false
                });
            };
            var done = function doneFn() {
                return postMessage({
                    id: data["id"],
                    finished: true
                });
            };
            return db.each(data["sql"], data["params"], callback, done, config);
        case "export":
            buff = db["export"]();
            result = {
                id: data["id"],
                buffer: buff
            };
            try {
                return postMessage(result, [result]);
            } catch (error) {
                return postMessage(result);
            }
        case "close":
            if (db) {
                db.close();
            }
            return postMessage({
                id: data["id"]
            });
        default:
            throw new Error("Invalid action : " + (data && data["action"]));
    }
}

function onError(err) {
    return postMessage({
        id: this["data"]["id"],
        error: err["message"]
    });
}

if (typeof importScripts === "function") {
    db = null;
    var sqlModuleReady = initSqlJs();
    self.onmessage = function onmessage(event) {
        return sqlModuleReady
            .then(onModuleReady.bind(event))
            .catch(onError.bind(event));
    };
}
